@@ -1,4 +1,4 @@
-/* Copyright (c) 1996,1997, 1998, 1999 Thorsten Kukuk
+/* Copyright (c) 1996,1997, 1998, 1999, 2000 Thorsten Kukuk
    This file is part of the NYS YP Server.
    Author: Thorsten Kukuk <kukuk@suse.de>
 
@@ -26,6 +26,7 @@
 #include "system.h"
 #include "version.h"
 #include "yp.h"
+#include <alloca.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -96,7 +97,7 @@ write_data (datum key, datum data)
 static char *
 strapp (const char *str1, const char *str2)
 {
-  char buffer[strlen (str1) + strlen (str2) + 1];
+  char *buffer = alloca(strlen (str1) + strlen (str2) + 1);
 
   strcpy (buffer, str1);
   strcat (buffer, str2);
