@@ -18,13 +18,9 @@
 ** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
 ** Cambridge, MA 02139, USA.
 **
-** Author: Thorsten Kukuk <kukuk@uni-paderborn.de>
+** Author: Thorsten Kukuk <kukuk@suse.de>
 */
 
-#ifndef LINUT
-static const char rcsid[] = "$Id: yp_db.c,v 1.19 1998/06/07 08:36:40 kukuk Exp $";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -34,8 +30,8 @@ static const char rcsid[] = "$Id: yp_db.c,v 1.19 1998/06/07 08:36:40 kukuk Exp $
 #include <fcntl.h>
 #include <errno.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
-#include <malloc.h>
 #include <sys/param.h>
 
 #include "ypserv.h"
@@ -174,13 +170,9 @@ ypdb_nextkey (DB_FILE file, datum key)
   return tkey;
 }
 
-
 #else
 
-void
-ypdb_open ()
-{
-}
+#error "No database found or selected!"
 
 #endif
 
