@@ -473,15 +473,14 @@ sig_child (int sig)
 
   while ((pid = waitpid (-1, &st, WNOHANG)) > 0)
     {
-      yp_msg ("pid=%d\n", pid);
+      if (debug_flag)
+	yp_msg ("pid=%d\n", pid);
       --children;
     }
 
   if (children < 0)
     {
       yp_msg ("children is lower 0 (%i)!\n", children);
-      abort ();
-      children = 0;
     }
   else if (debug_flag)
     yp_msg ("children = %i\n", children);
